Learn R Programming

NNMoMo (version 0.1.0)

print.fitStMoMo_list: Print Method for the Output of the Fitting Method

Description

Method for printing the output of the fitting method. Gives fundamental infofmation about the object.

Usage

# S3 method for fitStMoMo_list
print(x, ...)

Value

Prints basic information about the fitStMoMo_list object to the console.

Arguments

x

An object of class fitStMoMo_list.

...

Further arguments passed to or from other methods.