Learn R Programming

NNMoMo (version 0.1.0)

summary.fitStMoMo_list: Summary Method for the Output of the Fitting Method

Description

Method for printing the summary of the fitting method. Gives detailed infofmation about the object.

Usage

# S3 method for fitStMoMo_list
summary(object, ...)

Value

Displays a summary of the fitStMoMo_list object in the console.

Arguments

object

An object of class fitStMoMo_list.

...

Further arguments passed to or from other methods.